<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author tomas@valenta.cz
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 * @author zbynek.krivka@seznam.cz
 * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
 * @author Jakub A. Těšínský (j@kub.cz)
 * @author mkucera66@seznam.cz
 * @author Zbyněk Křivka <krivka@fit.vutbr.cz>
 * @author Gerrit Uitslag <klapinklapin@gmail.com>
 */
$lang['menu']                  = 'Obnova zaspamovaných stránek';
$lang['filter']                = 'Hledat zaspamované stránky';
$lang['revert']                = 'Obnovit vybrané stránky';
$lang['reverted']              = '%s vrácena do verze %s';
$lang['removed']               = '%s odstraněna';
$lang['revstart']              = 'Obnova stránek začala. Tento proces může trvat dlouho. Pokud
skriptu vyprší čas, budete muset obnovovat po menších blocích
stránek.';
$lang['revstop']               = 'Proces obnovy stránek byl úspěšně dokončen.';
$lang['note1']                 = 'Poznámka: toto vyhledávání je citlivé na velikost písmen';
$lang['note2']                 = 'Poznámka: tato stránka bude obnovena na poslední verzi, která
neobsahovala dané spamové slovo <i>%s</i>.';
